<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="ko" sourcelanguage="">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Behavior</source>
        <translation>행동</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Automatically save documents</source>
        <translation>자동저장</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Restore window geometry</source>
        <translation>창 복원</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Open external links in ReText window</source>
        <translation>외부 링크로 열기</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="184"/>
        <source>Editor</source>
        <translation>에디터</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Highlight current line</source>
        <translation>현재 줄 강조하기</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Show line numbers</source>
        <translation>줄 번호 보이기</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Tab key inserts spaces</source>
        <translation>탭키로 스페이스 넣기</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Tabulation width</source>
        <translation>표 작성 폭</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Interface</source>
        <translation>인터페이스</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Icon theme name</source>
        <translation>아이콘 테마 이름</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Stylesheet file</source>
        <translation>스타일시트 파일</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Markdown syntax extensions (comma-separated)</source>
        <translation>마크다운 구문 확장 (컴마분리)</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="166"/>
        <source>Help</source>
        <translation>도움</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Enable synchronized scrolling for Markdown</source>
        <translation>동시 스크롤 활성화</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Draw vertical line at column</source>
        <translation>세로줄 긋기</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Automatically open last documents on startup</source>
        <translation>실행시 마지막 문서 자동열기</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="91"/>
        <source>Using configuration file at:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Number of recent documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Default preview state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Line numbers are relative to current line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Enable soft wrap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Show document stats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Hide toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Hide tabs bar when there is only one tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Show full path in window title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="185"/>
        <source>Live preview</source>
        <translation type="unfinished">실시간 미리보기</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="186"/>
        <source>Normal preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Ordered list mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Show directory tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="109"/>
        <source>Working directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="191"/>
        <source>Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="192"/>
        <source>Cursor Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="193"/>
        <source>Wrapped Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="198"/>
        <source>Increment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="199"/>
        <source>Repeat</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DirectorySelectButton</name>
    <message>
        <location filename="../ReText/config.py" line="60"/>
        <source>Select directory to open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileDialogButton</name>
    <message>
        <location filename="../ReText/config.py" line="35"/>
        <source>(none)</source>
        <translation>(선택사항없음)</translation>
    </message>
</context>
<context>
    <name>FileSelectButton</name>
    <message>
        <location filename="../ReText/config.py" line="52"/>
        <source>Select file to open</source>
        <translation>파일 선택</translation>
    </message>
</context>
<context>
    <name>InsertTableDialog</name>
    <message>
        <location filename="../ReText/tabledialog.py" line="27"/>
        <source>Insert table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/tabledialog.py" line="36"/>
        <source>Number of rows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/tabledialog.py" line="37"/>
        <source>Number of columns</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../ReText/dialogs.py" line="44"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>지역이름 입력 (예: en_US)</translation>
    </message>
    <message>
        <location filename="../ReText/dialogs.py" line="50"/>
        <source>Set as default</source>
        <translation>기본값으로 설정</translation>
    </message>
</context>
<context>
    <name>Proxy</name>
    <message>
        <location filename="../ReText/fakevimeditor.py" line="61"/>
        <source>No write since last change (add ! to override)</source>
        <translation>마지막 수정 후 변경사항 없음(덮어쓰려면 !을 추가하세요)</translation>
    </message>
    <message>
        <location filename="../ReText/fakevimeditor.py" line="118"/>
        <source>Information</source>
        <translation>정보</translation>
    </message>
</context>
<context>
    <name>ReTextEdit</name>
    <message>
        <location filename="../ReText/editor.py" line="460"/>
        <source>Save image</source>
        <translation>이미지 저장</translation>
    </message>
    <message>
        <location filename="../ReText/editor.py" line="460"/>
        <source>Images (*.png *.jpg)</source>
        <translation>이미지 (*.png *.jpg)</translation>
    </message>
    <message>
        <location filename="../ReText/editor.py" line="248"/>
        <source>Add to dictionary</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextTab</name>
    <message>
        <location filename="../ReText/tab.py" line="185"/>
        <source>New document</source>
        <translation>새 문서</translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="190"/>
        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
        <translation>파일 내용을 파싱할 수 업습니다. &lt;a href=&quot;%s&quot;&gt;필수 모듈&lt;/a&gt; 가 있는지 보고 설치하세요!</translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="497"/>
        <source>Create missing file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="497"/>
        <source>The file &apos;%s&apos; does not exist.

Do you want to create it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="530"/>
        <source>File could not be created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="530"/>
        <source>Could not create file &apos;%s&apos;: %s</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="../ReText/window.py" line="567"/>
        <source>New document</source>
        <translation>새로운 문서</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="94"/>
        <source>File toolbar</source>
        <translation>파일 툴바</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="96"/>
        <source>Edit toolbar</source>
        <translation>툴바 에디트</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="98"/>
        <source>Search toolbar</source>
        <translation>툴바 찾기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="102"/>
        <source>New</source>
        <translation>새로 열기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="104"/>
        <source>Open</source>
        <translation>열기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="112"/>
        <source>Save</source>
        <translation>저장하기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="115"/>
        <source>Save as</source>
        <translation>다른이름으로 저장</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="123"/>
        <source>Print</source>
        <translation>출력</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="125"/>
        <source>Print preview</source>
        <translation>미리보기 출력</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="127"/>
        <source>View HTML code</source>
        <translation>HTML 코드 보기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="132"/>
        <source>Find text</source>
        <translation>문자 찾기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="137"/>
        <source>Preview</source>
        <translation>미리보기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="147"/>
        <source>Live preview</source>
        <translation>실시간 미리보기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="164"/>
        <source>Fullscreen mode</source>
        <translation>전체화면</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="174"/>
        <source>Quit</source>
        <translation>나가기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="177"/>
        <source>Undo</source>
        <translation>되돌리기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="179"/>
        <source>Redo</source>
        <translation>다시하기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="181"/>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="183"/>
        <source>Cut</source>
        <translation>잘라내기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="185"/>
        <source>Paste</source>
        <translation>붙여넣기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="200"/>
        <source>Enable</source>
        <translation>활성화</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="201"/>
        <source>Set locale</source>
        <translation>언어 설정</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="275"/>
        <source>Open recent</source>
        <translation>최근문서 열기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="213"/>
        <source>Next</source>
        <translation>다음</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="215"/>
        <source>Previous</source>
        <translation>이전</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="226"/>
        <source>Get help online</source>
        <translation>온라인 도움</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="230"/>
        <source>About Qt</source>
        <translation>Qt란?</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="265"/>
        <source>Symbols</source>
        <translation>심볼</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="270"/>
        <source>&amp;File</source>
        <translation>파일</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="271"/>
        <source>&amp;Edit</source>
        <translation>에디트</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="272"/>
        <source>&amp;Help</source>
        <translation>도움</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="288"/>
        <source>Export</source>
        <translation>내보내기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="313"/>
        <source>Spell check</source>
        <translation>스펠링 체크</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="372"/>
        <source>Search</source>
        <translation>찾기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="377"/>
        <source>Case sensitively</source>
        <translation>대소문자 구분</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="755"/>
        <source>Please, save the file somewhere.</source>
        <translation>파일을 저장해주십시오</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="871"/>
        <source>Select one or several files to open</source>
        <translation>열기를 할 파일, 파일들을 선택하십시오</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1289"/>
        <source>Supported files</source>
        <translation>파일 서포팅</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1289"/>
        <source>All files (*)</source>
        <translation>모든 파일들 (*)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="933"/>
        <source>Plain text (*.txt)</source>
        <translation>일반 텍스트 (*.txt)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1011"/>
        <source>Save file</source>
        <translation>파일 저장</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1001"/>
        <source>Export document to ODT</source>
        <translation>ODT로 내보내기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1001"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>텍스트파일로 열기 (*.odt)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1011"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>HTML 파일들 (*.html *.htm)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1060"/>
        <source>Export document to PDF</source>
        <translation>PDF로 내보내기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1060"/>
        <source>PDF files (*.pdf)</source>
        <translation>PDF파일 (*.pdf)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1087"/>
        <source>Print document</source>
        <translation>문서 출력</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1110"/>
        <source>Export document</source>
        <translation>문서 내보내기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1251"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>문서가 변경되었습니다. 저장하시겠습니까?</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1279"/>
        <source>HTML code</source>
        <translation>HTML 코드</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1307"/>
        <source>Simple but powerful editor for Markdown and reStructuredText</source>
        <translation>마크다운과 리스트럭트텍스트를 위한 심플하지만 강력한 에디터</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1307"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>원작자 : Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1307"/>
        <source>Markdown syntax</source>
        <translation>마크다운 구문</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1307"/>
        <source>reStructuredText syntax</source>
        <translation>리스트럭트텍스트 구문</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="212"/>
        <source>Show directory</source>
        <translation>디렉토리 보기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="979"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>저장 불가[읽기 전용]</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="245"/>
        <source>Bold</source>
        <translation>굵은 글꼴</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="247"/>
        <source>Italic</source>
        <translation>이탤릭체</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="249"/>
        <source>Underline</source>
        <translation>밑줄</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="325"/>
        <source>Formatting</source>
        <translation>서식 지정</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="227"/>
        <source>About ReText</source>
        <translation>ReText란?</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="202"/>
        <source>Use WebKit renderer</source>
        <translation>웹킷 렌더러 사용</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1131"/>
        <source>Failed to execute the command:</source>
        <translation>명령수행에 실패</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="936"/>
        <source>%s files</source>
        <comment>Example of final string: Markdown files</comment>
        <translation>%s 파일</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="322"/>
        <source>Default markup</source>
        <translation>기존 마크업</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="671"/>
        <source>Preferences</source>
        <translation>선택</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="106"/>
        <source>Set encoding</source>
        <translation>인코딩 설정</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="910"/>
        <source>Select file encoding from the list:</source>
        <translation>목록에서 파일 인코딩 선택</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1231"/>
        <source>Reload</source>
        <translation>리로드</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="117"/>
        <source>Next tab</source>
        <translation>다음 탭</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="119"/>
        <source>Previous tab</source>
        <translation>이전 탭</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="153"/>
        <source>Table editing mode</source>
        <translation>표에디트모드</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="159"/>
        <source>FakeVim mode</source>
        <translation>페이크빔 모드</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1214"/>
        <source>This file has been deleted by other application.
Please make sure you save the file before exit.</source>
        <translation>이 파일은 다른 앱에 의해 삭제되었습니다. 종료 전에 저장을 꼭 해주십시오.</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1222"/>
        <source>This document has been modified by other application.
Do you want to reload the file (this will discard all your changes)?
</source>
        <translation>이 파일은 다른 앱에 의해 삭제되었습니다. 이 파일을 리로드 하길 원합니까(이것은 당신의 변경사항을 버릴겁니다)?</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1227"/>
        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
        <translation>파일을 리로드 하지 않는다면, 데이터 손실 방지를 위해 세션에서 자동저장모드가 비활성화됩니다.</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="128"/>
        <source>Change editor font</source>
        <translation>에디터 글꼴 변경</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="130"/>
        <source>Change preview font</source>
        <translation>미리보기 글꼴 바꾸기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1307"/>
        <source>ReText %s (using PyMarkups %s)</source>
        <translation>ReText %s (PyMarkups %s 사용)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="222"/>
        <source>Close</source>
        <translation>닫기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1172"/>
        <source>Alt text</source>
        <translation>Alt속성 텍스트</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1173"/>
        <source>URL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1173"/>
        <source>Link text</source>
        <translation>링크 텍스트</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="217"/>
        <source>Replace</source>
        <translation>바꾸기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="219"/>
        <source>Replace all</source>
        <translation>모두바꾸기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="375"/>
        <source>Replace with</source>
        <translation>~으로 바꾸기</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="956"/>
        <source>Cannot save to file which is open in another tab!</source>
        <translation>다른 탭에 열려있는 파일은 저장하지 못합니다.</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="207"/>
        <source>Use WebEngine (Chromium) renderer</source>
        <translation>웹 엔진(크로뮴) 렌더러</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="121"/>
        <source>Close tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="719"/>
        <source>Go to line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="151"/>
        <source>Insert table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="156"/>
        <source>Insert images by file path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="187"/>
        <source>Paste image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="189"/>
        <source>Move line up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="191"/>
        <source>Move line down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="719"/>
        <source>Type the line number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1034"/>
        <source>Unrecognized paperSize setting &quot;%s&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1289"/>
        <source>Select one or several images to open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextInfoArea</name>
    <message>
        <location filename="../ReText/editor.py" line="651"/>
        <source>%d w | %d a | %d c</source>
        <comment>count of words, alphanumeric characters, all characters</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../ReText/__main__.py" line="88"/>
        <source>Open the files in preview mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/__main__.py" line="90"/>
        <source>Create a new window even if there is an existing one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/__main__.py" line="94"/>
        <source>List of files to open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
